[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://dev.to/frostming/a-review-pipenv-vs-poetry-vs-pdm-39b4)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
![Python](https://img.shields.io/badge/python-3.8%7C3.9%7C3.10-green)
![Doc](doc_badge.svg)
[![Coverage](cov_badge.svg)](../coverage/index.html)
[![Versioning](https://badgen.net/badge/semver/2.0.0/green)](https://semver.org/spec/v2.0.0.html)

# Quick look

A webapp to generate QR codes

# Build the doc

Just run:

    pdm doc

This will create the doc in htmldoc

A few guidelines for updating the doc
https://sphinxcontrib-napoleon.readthedocs.io/en/latest/example_google.html
